==> fdscli-0.1.15.tar.gz: fdscli-0.1.15/fdscli/utils/byte_converter.py <==
'''
Created on Dec 22, 2015

@author: nate
'''

class ByteConverter(object):
    '''
    This class will convert size objects into a reasonable string representation
    '''
    KB = 1024
    MB = KB*KB
    GB = MB*KB
    TB = GB*KB
    PB = TB*KB
    EB = PB*KB
    
    byteStr = "bytes"
    kbStr = "KB"
    mbStr = "MB"
    gbStr = "GB"
    tbStr = "TB"
    pbStr = "PB"
    ebStr = "EB"
    
    @staticmethod
    def convertBytesToString( byte_value=0, decimal_places=2):
        '''
        Take some bytes and turn them into a nice printable string with units
        '''
        num_value = byte_value
        unit_value = ByteConverter.byteStr
        
        if byte_value < ByteConverter.KB:
            num_value = byte_value
            unit_value = ByteConverter.byteStr
        elif  byte_value < ByteConverter.MB:
            num_value = byte_value/ByteConverter.KB 
            unit_value = ByteConverter.kbStr;
        elif byte_value < ByteConverter.GB:
            num_value = byte_value / ByteConverter.MB
            unit_value = ByteConverter.mbStr;
        elif byte_value < ByteConverter.TB:
            num_value = byte_value / ByteConverter.GB 
            unit_value = ByteConverter.gbStr;
        elif byte_value < ByteConverter.PB:
            num_value = byte_value / ByteConverter.TB
            unit_value = ByteConverter.tbStr;
        elif byte_value < ByteConverter.EB:
            num_value = byte_value / ByteConverter.PB
            unit_value = ByteConverter.pbStr;
        else:
            num_value = byte_value / ByteConverter.EB
            unit_value = ByteConverter.ebStr;

        return "{} {}".format( round( num_value, decimal_places ), unit_value )

==> fdscli-0.1.16.tar.gz: fdscli-0.1.16/fdscli/utils/byte_converter.py <==
'''
Created on Dec 22, 2015

@author: nate
'''
from __future__ import division

class ByteConverter(object):
    '''
    This class will convert size objects into a reasonable string representation
    '''
    KB = 1024
    MB = KB*KB
    GB = MB*KB
    TB = GB*KB
    PB = TB*KB
    EB = PB*KB
    
    byteStr = "bytes"
    kbStr = "KB"
    mbStr = "MB"
    gbStr = "GB"
    tbStr = "TB"
    pbStr = "PB"
    ebStr = "EB"
    
    @staticmethod
    def convertBytesToString( byte_value=0, decimal_places=2):
        '''
        Take some bytes and turn them into a nice printable string with units
        '''
        num_value = byte_value
        unit_value = ByteConverter.byteStr
        
        if byte_value < ByteConverter.KB:
            num_value = byte_value
            unit_value = ByteConverter.byteStr
        elif  byte_value < ByteConverter.MB:
            num_value = byte_value/ByteConverter.KB 
            unit_value = ByteConverter.kbStr;
        elif byte_value < ByteConverter.GB:
            num_value = byte_value / ByteConverter.MB
            unit_value = ByteConverter.mbStr;
        elif byte_value < ByteConverter.TB:
            num_value = byte_value / ByteConverter.GB 
            unit_value = ByteConverter.gbStr;
        elif byte_value < ByteConverter.PB:
            num_value = byte_value / ByteConverter.TB
            unit_value = ByteConverter.tbStr;
        elif byte_value < ByteConverter.EB:
            num_value = byte_value / ByteConverter.PB
            unit_value = ByteConverter.pbStr;
        else:
            num_value = byte_value / ByteConverter.EB
            unit_value = ByteConverter.ebStr;

        s = "{} {}".format( round( num_value, decimal_places ), unit_value )
        
        if unit_value == ByteConverter.byteStr:
            s = "{} {}".format( num_value, unit_value )
            
        return s
